@@ -3,18 +3,22 @@ Main interface for sms-voice service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.sms_voice import (
+    from mypy_boto3_sms_voice import (
         Client,
         SMSVoiceClient,
-        )
+    )
 
     session = boto3.Session()
 
     client: SMSVoiceClient = boto3.client("sms-voice")
     session_client: SMSVoiceClient = session.client("sms-voice")
+    ```
 """
-from mypy_boto3_sms_voice.client import SMSVoiceClient as Client, SMSVoiceClient
+from mypy_boto3_sms_voice.client import SMSVoiceClient
+
+Client = SMSVoiceClient
 
 
 __all__ = ("Client", "SMSVoiceClient")
